@@ -3,18 +3,14 @@
 # License: GNU General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
-from django.urls import reverse
 from unittest.mock import patch
 
-from swh.deposit.config import PRIVATE_CHECK_DEPOSIT
-
 
 def test_check_deposit_ready(swh_config, requests_mock_datadir, deposit_checker):
     """Check on a valid 'deposited' deposit should result in 'verified'
 
     """
-    deposit_check_url = reverse(PRIVATE_CHECK_DEPOSIT, args=["test", 1])
-    actual_result = deposit_checker.check(deposit_check_url=deposit_check_url)
+    actual_result = deposit_checker.check(collection="test", deposit_id=1)
     assert actual_result == {"status": "eventful"}
 
 
@@ -22,8 +18,7 @@ def test_check_deposit_rejected(swh_config, requests_mock_datadir, deposit_check
     """Check on invalid 'deposited' deposit should result in 'rejected'
 
     """
-    deposit_check_url = reverse(PRIVATE_CHECK_DEPOSIT, args=["test", 2])
-    actual_result = deposit_checker.check(deposit_check_url=deposit_check_url)
+    actual_result = deposit_checker.check(collection="test", deposit_id=2)
     assert actual_result == {"status": "failed"}
 
 
@@ -33,6 +28,5 @@ def test_check_deposit_rejected_exception(mock_requests, swh_config, deposit_che
 
     """
     mock_requests.side_effect = ValueError("simulated problem when checking")
-    deposit_check_url = reverse(PRIVATE_CHECK_DEPOSIT, args=["test", 3])
-    actual_result = deposit_checker.check(deposit_check_url=deposit_check_url)
+    actual_result = deposit_checker.check(collection="test", deposit_id=3)
     assert actual_result == {"status": "failed"}
